@@ -1,5 +1,6 @@
 # peter_cullen_burbery_python_functions/date_time_functions/__init__.py
 from .date_time_functions import (
     date_time_stamp,
-    generate_pdb_name_from_timestamp
+    generate_pdb_name_from_timestamp,
+    generate_prefixed_timestamp
 )
\ No newline at end of file
